import { Message } from '../connect';
export declare enum AuthType {
    BASIC = "BASIC",
    SSO = "SSO",
    JWT = "JWT",
    REFRESH = "REFRESH"
}
export type BasicAuthInfo = {
    type: AuthType & AuthType.BASIC;
    username: string;
    password: string;
};
export type SsoAuthInfo = {
    type: AuthType & AuthType.SSO;
    ssoToken: string;
};
export type RefreshAuthInfo = {
    type: AuthType & AuthType.REFRESH;
    username: string;
    refreshToken: string;
};
export type JwtAuthInfo = {
    type: AuthType & AuthType.JWT;
    jwt: string;
    domain: string;
};
export type AuthInfo = BasicAuthInfo | SsoAuthInfo | JwtAuthInfo | RefreshAuthInfo;
export type LoginResult = {
    authToken: string;
    refreshToken: string;
    username: string;
    profiles: string[];
    permissions: string[];
    sessionId: string;
};
export interface LogoutResult {
    success: boolean;
    error?: string;
}
export declare class AuthError extends Error {
    sent: Message;
    received?: Message;
    constructor(sent: Message, received?: Message, message?: string);
    isIgnorableError(): boolean;
    getMessageError(): string;
    getDetailsError(): string;
    hasPasswordExpiredError(): boolean;
    hasErrorCode(code: string): boolean;
    private errorDetailFormatter;
}
//# sourceMappingURL=auth.types.d.ts.map