import { AuthInfo, LoginResult } from '../auth/auth.types';
export declare enum MessageType {
    LOGON_ACK = "LOGON_ACK",
    LOGON_NACK = "LOGON_NACK",
    LOGOFF_ACK = "LOGOFF_ACK",
    LOGOFF_NACK = "LOGOFF_NACK",
    HEARTBEAT_PING = "HEARTBEAT_PING",
    HEARTBEAT_PONG = "HEARTBEAT_PONG",
    MORE_ROWS = "MORE_ROWS",
    MSG_ACK = "MSG_ACK",
    MSG_NACK = "MSG_NACK",
    LOGOUT_ACK = "LOGOUT_ACK",
    LOGOUT_NACK = "LOGOUT_NACK",
    QUERY_UPDATE = "QUERY_UPDATE"
}
export declare enum EventMessageType {
    EVENT_LOGIN_AUTH = "EVENT_LOGIN_AUTH",
    EVENT_LOGIN_AUTH_ACK = "EVENT_LOGIN_AUTH_ACK",
    EVENT_LOGIN_AUTH_NACK = "EVENT_LOGIN_AUTH_NACK",
    EVENT_LOGOUT = "EVENT_LOGOUT",
    DATA_LOGON = "DATA_LOGON",
    DATA_LOGOFF = "DATA_LOGOFF",
    META_REQUEST = "META_REQUEST",
    JSON_SCHEMA_REQUEST = "JSON_SCHEMA_REQUEST",
    RESOURCES_REQUEST = "RESOURCES_REQUEST",
    EVENT_CHANGE_USER_PASSWORD = "EVENT_CHANGE_USER_PASSWORD",
    EVENT_SELF_SERVICE_PASSWORD_RESET = "EVENT_SELF_SERVICE_PASSWORD_RESET",
    EVENT_PASSWORD_RESET_ACTION = "EVENT_PASSWORD_RESET_ACTION"
}
export declare enum MessageCode {
    SESSION_NOT_FOUND = "SESSION_NOT_FOUND",
    UNKNOWN_MESSAGE_TYPE = "UNKNOWN_MESSAGE_TYPE"
}
export declare namespace MessageDetails {
    type LoginBasic = {
        USER_NAME: string;
        PASSWORD: string;
    };
    type LoginSSO = {
        SSO_TOKEN: string;
    };
    type LoginJWT = {
        JWT: string;
        DOMAIN: string;
    };
    type Login = LoginBasic | LoginSSO;
    type ChangePassword = {
        OLD_PASSWORD: string;
        NEW_PASSWORD: string;
    };
    type ResetPassword = {
        USER_NAME: string;
    };
    type ForgotPassword = {
        USER_NAME: string;
        RETURN_URL: string;
    };
    type ForgotPasswordToken = {
        USER_NAME: string;
        RESET_TOKEN: string;
        NEW_PASSWORD: string;
    };
    type ExpirePassword = {
        USER_NAME: string;
        PASSWORD: string;
    };
    type RefreshToken = {
        REFRESH_AUTH_TOKEN: string;
    };
    type MoreRows = {
        SOURCE_REF: string;
    };
    type UpdateColumns = {
        SOURCE_REF: string;
        ADD_COLUMNS: string;
        DROP_COLUMNS: string;
    };
    type DataserverRequest = {
        DATASOURCE_NAME: string;
    };
    type MetaRequest = {
        FEATURE: string;
    };
    type Error = {
        ERROR: string;
    };
    type LoggedInSystemInfo = {
        DAYS_TO_PASSWORD_EXPIRY: number;
        FAILED_LOGIN_ATTEMPTS: number;
        HEARTBEAT_INTERVAL_SECS: number;
        LAST_LOGIN_DATETIME: number;
        NOTIFY_EXPIRY?: boolean;
        PRODUCT?: any[];
        SYSTEM?: any;
    };
}
export type MessageError = {
    CODE: MessageCode | string;
    TEXT: string;
};
export type Message<T = void | any> = {
    REPLY?: any[];
    CODE?: MessageCode | string;
    DETAILS?: T;
    LOGGED_OUT?: boolean;
    ERROR?: MessageError[];
    MESSAGE_TYPE?: MessageType | EventMessageType | string;
    PERMISSION?: string[];
    PROFILE?: string[];
    REFRESH_AUTH_TOKEN?: string;
    ROW?: any[];
    ROWS_COUNT?: number;
    SEQUENCE_ID?: number;
    SERVICE_NAME?: string;
    SESSION_AUTH_TOKEN?: string;
    SESSION_ID?: string;
    SOURCE_REF?: string;
    USER_NAME?: string;
};
export type RequestParams = {
    DETAILS?: any;
    REQUEST?: any;
};
export type CommitParams = {
    DETAILS: any;
    HOSTNAME?: string;
    IGNORE_WARNINGS?: boolean;
    VALIDATE?: boolean;
};
export declare const messageOrThrow: (message: Message) => Message<any>;
export interface MessageBuilder {
    createLoginMessage(credentials: AuthInfo): Message<MessageDetails.Login>;
    createLogoutMessage(loginResult?: LoginResult): Message;
    createDataLogonMessage(resourceName: string, params?: any): Message<MessageDetails.DataserverRequest>;
    createDataLogoffMessage<T = any>(sourceRef: string): Message<T>;
    createMoreRowsMessage(sourceRef: string): Message;
    createRequestMessage<T = any>(resourceName: string, params?: any): Message<T>;
    createMetaRequestMessage(resourceName: string, messageType?: EventMessageType): Message<MessageDetails.MetaRequest>;
    createCommitMessage<T = any>(eventName: string, params?: CommitParams): Message<T>;
    createRefreshTokenMessage(): Message<MessageDetails.RefreshToken>;
    createChangePasswordMessage(username: string, oldPassword: string, newPassword: string): Message<MessageDetails.ChangePassword>;
    createForgotPasswordMessage(username: string, returnUrl: string, requester?: string): Message<MessageDetails.ForgotPassword>;
    createForgotPasswordTokenMessage(username: string, resetToken: string, newPassword: string, requester?: string): Message<MessageDetails.ForgotPasswordToken>;
}
export declare const MessageBuilder: import("@microsoft/fast-foundation").InterfaceSymbol<MessageBuilder>;
//# sourceMappingURL=message.d.ts.map