import { BehaviorSubject, Observable, Observer, Subject, Subscription } from 'rxjs';
import { Message } from './message';
import { SocketReconnectOptions } from './reconnectStrategy';
export declare class SocketSubject<T> extends Subject<T> {
    constructor();
}
export declare class SocketObservable<T> extends Observable<T> {
    constructor(...args: any[]);
}
export { Subscription as SocketSubscription };
export type SocketConnectOptions = {
    alwaysOn?: boolean;
    connectObserver?: Observer<Message>;
    enableHeartbeat?: boolean;
    enableHeartbeatLogging?: boolean;
    enableMessageLogging?: boolean;
    heartbeatInterval?: number;
    proxyPath?: string;
};
export declare class SocketMessageHandler {
    constructor(message: Message, onMessage: Function, onError: Function, isSubscription: boolean);
    get sentMessage(): Message;
    get onReceivedMessage(): Function;
    get onReceivedError(): Function;
    get isSubscription(): boolean;
    private _message;
    private _onMessage;
    private _onError;
    private _isSubscription;
}
export interface Socket {
    isConnected: boolean;
    isReconnecting: boolean;
    hasValidSession: boolean;
    isConnectedSubject: BehaviorSubject<boolean>;
    connect(host: string, options?: SocketConnectOptions, reconnectOptions?: SocketReconnectOptions): Promise<boolean>;
    reset(): void;
    send<T>(message: Message<T | any>, needsHandling?: boolean): Promise<Message | any>;
    sendForStream<T>(message: Message<T | any>, onMessage: Function, onError: Function): Observable<Message>;
    socketMessages(): SocketSubject<Message>;
}
export declare const Socket: import("@microsoft/fast-foundation").InterfaceSymbol<Socket>;
//# sourceMappingURL=socket.d.ts.map