import { JSONSchema7 } from 'json-schema';
export type MetadataDetail = {
    NAME: string;
    TYPE: string;
    VALID_VALUES?: string;
    READ_ONLY?: boolean;
    OPTIONAL?: boolean;
    UI_LABEL?: string;
};
export type IndexDetail = {
    NAME: string;
    FIELDS: string;
};
export type Metadata = {
    FIELD?: MetadataDetail[];
    INDEXES?: IndexDetail[];
    REPLY_FIELD?: MetadataDetail[];
    REQUEST_FIELD?: MetadataDetail[];
    NAME?: string;
    TYPE?: string;
    ERROR?: string;
};
export type SchemaResponse = {
    INBOUND: JSONSchema7;
    OUTBOUND: JSONSchema7;
    MESSAGE_TYPE: string;
    SOURCE_REF: string;
};
export type RowData = {
    ROW_REF: string;
};
export type ServerRow = {
    DETAILS: {
        OPERATION: 'INSERT' | 'MODIFY' | 'DELETE';
        ROW_REF: string;
    };
};
export type RawDataServerResult = {
    MESSAGE_TYPE: string;
    ROW: ServerRow[];
    SOURCE_REF: string;
    MORE_ROWS: boolean;
    ROWS_COUNT: number;
    SEQUENCE_ID: number;
};
export type FilteredDataServerResult = {
    inserts?: RowData[];
    deletes?: RowData[];
    updates?: RowData[];
    SOURCE_REF?: string;
};
export type RequestServerResult = {
    SOURCE_REF?: string;
    REPLY: any[];
    MESSAGE_TYPE?: string;
};
export declare enum FieldTypeEnum {
    STRING = "STRING",
    NUMBER = "NUMBER",
    BOOLEAN = "BOOLEAN",
    ENUM = "ENUM",
    DATE = "DATE",
    DATETIME = "DATETIME",
    CUSTOM = "CUSTOM"
}
export type FieldMetadata = {
    name: string;
    displayName?: string;
    type: FieldTypeEnum;
    enumOptions?: Array<any>;
    enumMultiple?: boolean;
    required?: boolean;
    readOnly?: boolean;
    component?: string;
};
export declare const TYPES_MAP: {
    STRING: FieldTypeEnum;
    ENUM: FieldTypeEnum;
    BOOLEAN: FieldTypeEnum;
    INT: FieldTypeEnum;
    DOUBLE: FieldTypeEnum;
    BIGDECIMAL: FieldTypeEnum;
    DATE: FieldTypeEnum;
    DATETIME: FieldTypeEnum;
};
//# sourceMappingURL=metadata.types.d.ts.map