import { Observable } from 'rxjs';
const DEFAULT_RECONNECT_INTERVAL = 10000;
const MAX_RECONNECT_INTERVAL = 60000;
export const MAX_RECONNECT_ATTEMPTS = 10;
export var SocketReconnectStrategy;
(function (SocketReconnectStrategy) {
    SocketReconnectStrategy["Linear"] = "linear";
    SocketReconnectStrategy["Exponential"] = "exponential";
})(SocketReconnectStrategy || (SocketReconnectStrategy = {}));
export const retryInterval = (reconnectOptions, scheduler) => {
    return new Observable((observer) => {
        let count = 0;
        let timeoutId;
        function recursiveTimeout() {
            observer.next(count);
            clearTimeout(timeoutId);
            timeoutId = setTimeout(recursiveTimeout, scheduler(reconnectOptions, count));
            count = count + 1;
        }
        recursiveTimeout();
        return () => {
            clearTimeout(timeoutId);
        };
    });
};
export const exponentialScheduler = (reconnectOptions, attempt) => {
    const { reconnectInterval = DEFAULT_RECONNECT_INTERVAL } = reconnectOptions;
    const baseInterval = reconnectInterval > MAX_RECONNECT_INTERVAL ? MAX_RECONNECT_INTERVAL : reconnectInterval;
    const attemptsBreakPoint = Math.round(Math.log2(MAX_RECONNECT_INTERVAL / baseInterval));
    return baseInterval * Math.pow(2, (attempt % attemptsBreakPoint));
};
export const linearScheduler = (reconnectOptions, attempt) => {
    const { reconnectInterval = DEFAULT_RECONNECT_INTERVAL } = reconnectOptions;
    const baseInterval = reconnectInterval > MAX_RECONNECT_INTERVAL ? MAX_RECONNECT_INTERVAL : reconnectInterval;
    return baseInterval;
};
//# sourceMappingURL=reconnectStrategy.js.map