import { DI } from '@microsoft/fast-foundation';
class SessionService {
    constructor() {
        this.storageKeyPrefix = '';
        this.returnUrl = this.getSessionStorageItem('returnUrl') || '';
    }
    deleteUserFromSessionStorage() {
        const storageKeys = ['authToken', 'refreshToken', 'sessionId', 'ssoToken'];
        storageKeys.forEach((key) => this.removeSessionStorageItem(key));
    }
    setStorageKeyPrefix(prefix) {
        this.storageKeyPrefix = `${prefix.replace(/\s/g, '')}/`;
    }
    setAuthResult(result) {
        this.setSessionStorageItem('authToken', result.SESSION_AUTH_TOKEN);
        this.setSessionStorageItem('refreshToken', result.REFRESH_AUTH_TOKEN);
        this.setSessionStorageItem('username', result.USER_NAME);
        this.setSessionStorageItem('sessionId', result.SESSION_ID);
    }
    captureReturnUrl() {
        const { pathname, search, hash } = location;
        if (pathname === '/login') {
            return;
        }
        const path = `${pathname !== '/' ? pathname : ''}`;
        this.returnUrl = `${path}${search}${hash}`;
        this.setSessionStorageItem('returnUrl', this.returnUrl);
    }
    setItem(key, value, storage) {
        if (storage === 'local') {
            localStorage.setItem(this.storageKeyPrefix + key, value);
        }
        else {
            sessionStorage.setItem(this.storageKeyPrefix + key, value);
        }
    }
    getItem(key, storage) {
        if (storage === 'local')
            return localStorage.getItem(this.storageKeyPrefix + key);
        return sessionStorage.getItem(this.storageKeyPrefix + key);
    }
    removeItem(key, storage) {
        if (storage === 'local') {
            localStorage.removeItem(this.storageKeyPrefix + key);
        }
        else {
            sessionStorage.removeItem(this.storageKeyPrefix + key);
        }
    }
    setLocalStorageItem(key, value) {
        this.setItem(key, value, 'local');
    }
    setSessionStorageItem(key, value) {
        this.setItem(key, value, 'session');
    }
    getLocalStorageItem(key) {
        return this.getItem(key, 'local');
    }
    getSessionStorageItem(key) {
        return this.getItem(key, 'session');
    }
    removeLocalStorageItem(key) {
        this.removeItem(key, 'local');
    }
    removeSessionStorageItem(key) {
        this.removeItem(key, 'session');
    }
}
export const Session = DI.createInterface((x) => x.singleton(SessionService));
//# sourceMappingURL=session.js.map